@@ -10,7 +10,7 @@ use List::MoreUtils qw(none);
 use Scalar::Util qw(blessed);
 use Tags::HTML::Element::A;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -190,6 +190,8 @@ sub _value {
 		);
 	} elsif (ref $value eq 'ARRAY') {
 		$self->{'tags'}->put(@{$value});
+	} elsif (ref $value eq 'CODE') {
+		$value->($self);
 	} elsif (blessed($value) && $value->isa('Data::HTML::Element::A')) {
 		$self->{'_tags_html_a'}->init($value);
 		$self->{'_tags_html_a'}->process;
@@ -274,8 +276,27 @@ Returns undef.
 
 Process initialization before page run.
 
-Variable C<$data_ar> are data for table. Each item in array could be scalar,
-array with scalars or L<Data::HTML::Element::A> instance.
+Variable C<$data_ar> are data for table. Each item in array could be:
+
+=over
+
+=item * Scalar
+
+Add scalar variable to field.
+
+=item * Array with scalars
+
+Add scalar variables to field.
+
+=item * Code
+
+Run this code with argument C<$self> of this module.
+
+=item * L<Data::HTML::Element::A> instance
+
+Serialize link to field.
+
+=back
 
 Variable C<$no_data_value> contain information for situation when data in table not
 exists.
@@ -588,6 +609,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
